@@ -5,6 +5,9 @@
 #include <QList>
 #include <QListWidgetItem>
 
+#include "commentingwidget.h"
+#include "loginprompt.h"
+
 #include "appdownloader-comm/MaemoApplicationHandler.h"
 #include "appdownloader-comm/MaemoApplicationDetails.h"
 #include "appdownloader-comm/MaemoComment.h"
@@ -18,10 +21,12 @@ class ApplicationCommentsWidget : public QWidget {
     Q_OBJECT
     Q_DISABLE_COPY(ApplicationCommentsWidget)
 
+
 public:
     explicit ApplicationCommentsWidget(MaemoApplicationDetails*,MaemoApplicationHandler*,QWidget *parent = 0);
     virtual ~ApplicationCommentsWidget();
     void loadAllComments ();
+    enum closeWindow {LOGIN,COMMENTING};
 
 public slots:
     void commentApplication();
@@ -29,6 +34,7 @@ public slots:
     void updateStatus (QString);
     void loginPrompt();
     void logout();
+    void closeWindow (int);
 
 signals:
     void layerAdded(QWidget*,QString,QString);
@@ -39,8 +45,6 @@ protected:
 
 
 private:
-
-
     Ui::ApplicationCommentsWidget *m_ui;
     MaemoApplicationDetails *appDetails;
     QList <MaemoComment*>* comments;
@@ -49,7 +53,8 @@ private:
     int preload;
     bool more;
     MaemoApplicationHandler *applicationHandler;
-
+    LoginPrompt *login;
+    CommentingWidget *commentApp;
 
 
 };
