@@ -12,7 +12,7 @@ namespace Ui {
 class LoginPrompt : public QWidget {
     Q_OBJECT
 public:
-    explicit LoginPrompt(MaemoApplicationHandler *,QWidget *parent = 0);
+    explicit LoginPrompt(MaemoApplicationHandler *,int w,QWidget *parent = 0);
     ~LoginPrompt();
 
 public slots:
@@ -20,11 +20,13 @@ public slots:
 
 signals:
     void loggedIn (QString);
+    void deleteWidget(int);
 
 protected:
     void changeEvent(QEvent *e);
 private slots:
     void userLogin ();
+    void closeWidget ();
 
 
 private:
@@ -32,6 +34,7 @@ private:
     MaemoApplicationHandler *applicationHandler;
     QString username;
     LoadWidget *loading;
+    int id;
 };
 
 #endif // LOGINPROMPT_H
